SSANOVA decomposition of the ensemble of climate change responses using a Bayesian approach.
The different fields of the returned list contain n samples from the posterior distributions
of the different inferred quantities. In this first step, the residual errors are assumed iid
QUALYPSOSS.ANOVA.step1(lOpt, lDim, yMCMC, RK)list containing diverse information aboutwith the following fields:
g.MCMC: Smooth effects g: array n x nFull x K where
nFull is the number of possible combinations of predictors (discrete AND continuous),
nu.MCMC: Smooth effects nu, a list with matrices of eigen vectors
lambda.MCMC: Smoothing parameters: matrix n x K,
deltaRV.MCMC: Residual variance: vector of length n,
g.hat: Smooth effects estimates: matrix nFull x K where
nu.hat: Smooth effects estimates: a list with estimates of eigen vectors,
lambda.hat: Smoothing parameters estimates: vector of length K,
deltaRV.hat: Residual variance estimate.
logLK: vector of log-likelihood values of the draws
logPost: vector of log-posterior values of the draws
Schwarz: Schwarz criteria
BIC: BIC criteria
list of options, returned by QUALYPSOSS.check.option
list of dimensions
array nMCMC x nFull of climate change responses
large object containing the reproducing kernels, returned by QUALYPSOSS.get.RK
Guillaume Evin