Learn R Programming

qualypsoss (version 1.1.1)

QUALYPSOSS.ANOVA.step2: QUALYPSOSS.ANOVA.step2

Description

SSANOVA decomposition of the ensemble of climate change responses using a Bayesian approach. In this second step, we infer deltaRV (variance of the residual errors) and phi (autocorrelation lag-1) considering hetero-autocorrelated residual errors, conditionally to smooth effects inferred in QUALYPSOSS.ANOVA.step1

Usage

QUALYPSOSS.ANOVA.step2(lOpt, lDim, yMCMC, gSum.step1, deltaRV.step1)

Value

list containing diverse information aboutwith the following fields:

  • rho.MCMC: autocorrelation parameter of the AR(1) process: vector of length n

  • deltaRV.MCMC: Residual variance: vector of length n,

  • rho.hat: autocorrelation parameter estimate of the AR(1) process,

  • deltaRV.hat: Residual variance estimate.

Arguments

lOpt

list of options, returned by QUALYPSOSS.check.option

lDim

list of dimensions

yMCMC

array nMCMC x nFull of climate change responses

gSum.step1

sum of smooth effect estimates provided by QUALYPSOSS.ANOVA.step1

deltaRV.step1

residual variance estimate provided by QUALYPSOSS.ANOVA.step1

Author

Guillaume Evin