SSANOVA decomposition of the ensemble of climate change responses using a Bayesian approach.
In this second step, we infer deltaRV (variance of the residual errors) and phi (autocorrelation lag-1)
considering hetero-autocorrelated residual errors, conditionally to smooth effects inferred in QUALYPSOSS.ANOVA.step1
QUALYPSOSS.ANOVA.step3(
lOpt,
lDim,
yMCMC,
RK,
g.step1,
lambda.step1,
rho.step2,
deltaRV.step2
)list containing diverse information aboutwith the following fields:
g.MCMC: Smooth effects g: array n x nFull x K where
nFull is the number of possible combinations of predictors (discrete AND continuous),
g.hat: Smooth effects estimates: matrix nFull x K where
nFull is the number of possible combinations of predictors (discrete AND continuous),
Schwarz: Schwarz criteria
BIC: BIC criteria
list of options, returned by QUALYPSOSS.check.option
list of dimensions
array nMCMC x nFull of climate change responses
large object containing the reproducing kernels, returned by QUALYPSOSS.get.RK
smooth effect estimates provided by QUALYPSOSS.ANOVA.step1
smooth parameter estimates provided by QUALYPSOSS.ANOVA.step1
lag-1 autocorrelation estimate provided by QUALYPSOSS.ANOVA.step2
residual variance estimate provided by QUALYPSOSS.ANOVA.step2
Guillaume Evin