compute different objects used for the application of Smoothing-Splines ANOVA (SS-ANOVA), these objects being processed outputs of the scenario characteristics
QUALYPSOSS.process.scenario(scenAvail, predContUnique)list containing diverse information aboutwith the following fields:
scenAvail: Record first argument of the function,
predContUnique: Record second argument of the function,
XFull: data.frame with all possible combinations of predictors (continuous AND discrete),
nFull: number of rows of XFull,
nK: Number of columns of ScenAvail (i.e. number of discrete predictors),
predDiscreteUnique: List containing possible values for each discrete predictor.
matrix of scenario characteristics nS x nK.
(optional) unique values of continuous predictors.
Guillaume Evin