Learn R Programming

qualypsoss (version 1.1.1)

Y: climate projections of mean winter (DJF) temperature over the SREX region CEU simulated by 20 combinations of CMIP5 GCMs and RCMs for the period 1971-2099

Description

climate projections of mean winter (DJF) temperature over the SREX region CEU simulated by 20 combinations of CMIP5 GCMs and RCMs for the period 1971-2099

Usage

data(Y)

Arguments

Format

matrix 129 years x 20 scenarios

Author

Guillaume Evin guillaume.evin@inrae.fr

References

Seneviratne, S. I. et al. Changes in Climate Extremes and their Impacts on the Natural Physical Environment, in: Managing the Risks of Extreme Events and Disasters to Advance Climate Change Adaptation: Special Report of the Intergovernmental Panel on Climate Change, edited by: Field, C., Barros, V., Stocker, T., and Dahe, Q., Cambridge University Press, Cambridge, 109-230, https://doi.org/10.1017/CBO9781139177245.006, 2012