Extract climate response for one time series z
extract.climate.response(
ClimateProjections,
predCont,
predContUnique,
nMCMC,
lam,
uniqueFit,
spar = spar,
listCR = NULL
)list with the following fields:
phi.MCMC: MCMC draws of climate response
eta.MCMC: MCMC draws of deviation from the climate response
deltaIV.MCMC: MCMC draws of deltaRV
listCR: list of objects for faster computation on grids
matrix of climate projections
matrix of continuous predictor corresponding to the climate projections
vector of predictors for which we need fitted climate reponses
number of MCMC samples
fixed smoothing parameter lambda
logical value indicating if only one fit is applied
smoothing parameter spar in smooth.spline: must be greater than zero
list of objects for the extraction of the climate response
Guillaume Evin