formatQUALYPSSoutput
formatQUALYPSSoutput(
lOpt,
lDim,
lScen,
ANOVA.step1,
ANOVA.step2,
ANOVA.step3,
climResponse,
change.variable
)list with the following fields:
POINT: list containing the mean estimate of different quantities: RESIDUALVAR
(residual variability), INTERNALVAR (internal variability), GRANDMEAN (grand mean for all time
steps), MAINEFFECT (list with one item per discrete predictor i, containing matrices nT x
nEffi, where nEffi is the number of possible values for the discrete predictor i).
EFFECTVAR, uncertainty related to the different main effect, TOTVAR Total variability,
DECOMPVAR, decomposition of the total variability (percentages) for the different components,
CONTRIB_EACH_EFFECT, contribution of each individual effects (percentages) to the corr. effect uncertainty.
BAYES: list containing quantiles of different estimated quantities, listed in POINT.
MCMC: MCMC draws for the different quantities.
list of options, returned by QUALYPSOSS.check.option
list of dimensions
list of scenario characteristics, output from QUALYPSOSS.process.scenario
list provided by QUALYPSOSS.ANOVA.step1
list provided by QUALYPSOSS.ANOVA.step2
list provided by QUALYPSOSS.ANOVA.step3
list containing phi, eta, provided by extract.climate.response
list containing phiStar, etaStar, provided by compute.change.variable
Guillaume Evin