Learn R Programming

qualypsoss (version 1.1.1)

get.det.AR1: get.det.AR1 return the determinant of the matrix provided by get.matrix.AR1

Description

get.det.AR1 return the determinant of the matrix provided by get.matrix.AR1

Usage

get.det.AR1(nP, rho, nMO)

Value

determinant of the AR1 matrix

Arguments

nP

number of continuous predictors (e.g. future times)

rho

AR(1) correlation parameter in (-1,1)

nMO

number of possible simulation chains (missing and non-missing)

Author

Guillaume Evin