get.logdet.W: get.logdet.W
Return the logarithm of the determinant of the matrix W
Description
get.logdet.W
Return the logarithm of the determinant of the matrix W
Usage
get.logdet.W(weight.hetero, nMO, nP, rho)
Value
logarithm of the determinant of the matrix W
Arguments
- weight.hetero
output of get.vec.weight.hetero
- nMO
number of possible simulation chains (missing and non-missing)
- nP
number of continuous predictors (e.g. future times)
- rho
AR(1) correlation parameter in (-1,1)