Learn R Programming

qualypsoss (version 1.1.1)

get.matrix.AR1.inv: get.matrix.AR1.inv return the inverse matrix of AR(1) correlations corresponding to the entire ensemble

Description

get.matrix.AR1.inv return the inverse matrix of AR(1) correlations corresponding to the entire ensemble

Usage

get.matrix.AR1.inv(nP, rho, nMO)

Value

inverse matrix n x n of AR(1) correlations where coden is the total number of predictions (all the predictions for all the possible simulation chains)

Arguments

nP

number of continuous predictors (e.g. future times)

rho

AR(1) correlation parameter in (-1,1)

nMO

number of possible simulation chains (missing and non-missing)

Author

Guillaume Evin