Learn R Programming

qualypsoss (version 1.1.1)

get.matrix.KMS: get.matrix.KMS Return the square Kac-Murdoch-Szego matrix for a rho correlation and n lines/colums

Description

get.matrix.KMS Return the square Kac-Murdoch-Szego matrix for a rho correlation and n lines/colums

Usage

get.matrix.KMS(n, rho)

Value

n x n Kac-Murdock-Szego matrix

Arguments

n

nummber of lines/columns of the square matrix

rho

correlation parameter in [0,1]

Author

Guillaume Evin

References

Kac, M., W. L. Murdock, and G. Szego. 1953. 'On the Eigen-Values of Certain Hermitian Forms' Journal of Rational Mechanics and Analysis 2: 767-800.