get.matrix.Winv return the inverse matrix of W = V x C x V for the treatment of heteroscedastic and AR(1) errors see Wang (2011) section 5.3 for further details
get.matrix.Winv(weight.hetero, nMO, nP, rho)inverse matrix n x n of weights where coden is the total number of predictions (all the predictions for all the possible simulation chains)
output of get.vec.weight.hetero
number of possible simulation chains (missing and non-missing)
number of continuous predictors (e.g. future times)
AR(1) correlation parameter in (-1,1)
Guillaume Evin
Wang, Y. 2011. 'Spline Smoothing with Heteroscedastic and/or Correlated Errors' Smoothing Splines. Chapman and Hall/CRC. https://doi.org/10.1201/b10954-11.