Learn R Programming

qualypsoss (version 1.1.1)

get.matrix.hetero.inv: get.matrix.hetero.inv returns the inverse of the matrix of weights for the computation of heteroscedastic errors corresponding to the entire ensemble

Description

get.matrix.hetero.inv returns the inverse of the matrix of weights for the computation of heteroscedastic errors corresponding to the entire ensemble

Usage

get.matrix.hetero.inv(weight.hetero, nMO)

Value

inverse matrix n x n of weights where coden is the total number of predictions (all the predictions for all the possible simulation chains)

Arguments

weight.hetero

output of get.vec.weight.hetero

nMO

number of possible simulation chains (missing and non-missing)

Author

Guillaume Evin