get.target.density.rho Return the log-density of the full conditional distribution for the parameter rho
get.target.logdensity.rho(nFull, deltaRV, distSS, weight.hetero, nMO, nP, rho)log-density of the full conditional distribution
nP x nMO
variance of the residual terms for the max value of the continuous predictor
sum of square distances between the climate change responses and the ANOVA model
output of get.vec.weight.hetero
number of possible simulation chains (missing and non-missing)
number of continuous predictors (e.g. future times)
AR(1) correlation parameter in (-1,1)
Guillaume Evin