get.vec.weight.hetero returns the vector of weights for the computation of heteroscedastic errors corresponding to one simulation chain
get.vec.weight.hetero(nP, type.weight.hetero)vector of square roots of weights of the same length than predContUnique
length of the continuous predictor for which we want to obtain the prediction (e.g. time) we suppose that continuous predictor is regularly spaced (e.g. 1990,2000,2010,...)
"constant" (homoscedastic) or "linear" (heteroscedastic)
Guillaume Evin