Plot prediction of grand mean ensemble. By default, we plot the credible interval corresponding to a probability 0.95.
plotQUALYPSOSSgrandmean(
QUALYPSOSSOUT,
CIlevel = c(0.025, 0.975),
lim = NULL,
col = "black",
xlab = "Continuous predictor",
ylab = "Grand mean",
addLegend = T,
...
)output from QUALYPSOSS
probabilities for the credible intervals, default is equal to c(0.025,0.975)
y-axis limits (default is NULL)
color for the overall mean and the credible interval
x-axis label
y-axis label
if TRUE, a legend is added
additional arguments to be passed to plot
Guillaume Evin