Learn R Programming

qualypsoss (version 1.1.1)

predGlobTemp: Annual average of global temperatures simulated by different CMIP5 GCMs at the planetary scale for the period 1971-2099

Description

Annual average of global temperatures simulated by different CMIP5 GCMs at the planetary scale for the period 1971-2099

Usage

data(predGlobTemp)

Arguments

Format

matrix 129 years x 20 scenarios

Author

Guillaume Evin guillaume.evin@inrae.fr