Learn R Programming

qualypsoss (version 1.1.1)

predGlobTempUnique: Equally spaced vector of simulated global temperatures over the period 1971-2099 for the RCP8.5

Description

Equally spaced vector of simulated global temperatures over the period 1971-2099 for the RCP8.5

Usage

data(predGlobTempUnique)

Arguments

Format

vector of length 13

Author

Guillaume Evin guillaume.evin@inrae.fr