get.matrix.AR1 return the matrix of AR(1) correlations corresponding to the entire ensemble
get.matrix.AR1(nP, rho, nMO)C matrix n x n of AR(1) correlations where coden is the total number of predictions (all the predictions for all the possible simulation chains)
number of continuous predictors (e.g. future times)
AR(1) correlation parameter in (-1,1)
number of possible simulation chains (missing and non-missing)
Guillaume Evin