get.matrix.hetero.inv returns the inverse of the matrix of weights for the computation of heteroscedastic errors corresponding to the entire ensemble
get.matrix.hetero.inv(weight.hetero, nMO)inverse matrix n x n of weights where coden is the total number of predictions (all the predictions for all the possible simulation chains)
output of get.vec.weight.hetero
number of possible simulation chains (missing and non-missing)
Guillaume Evin